vi_text_input_formatter library
Classes
- ViTextInputFormatter
- Converts the current word to Vietnamese, mimicking Unikey (Unicode, Telex)
Constants
-
giAndModifierToGi
→ const Map<
String, String> - Helper map to convert from 'gi' to new 'gi' after insertion
-
giAndModifierToGiAndVowel
→ const Map<
String, String> - Helper map to convert from 'gi'+modifier to new 'gi'+vowel after insertion
-
leadingConsonants
→ const List<
String> - Vietnamese leading consonants. Ordered by length
-
modifiers
→ const List<
String> - Vietnamese modifiers.
-
trailingConsonants
→ const List<
String> - Vietnamese trailing consonants. Ordered by length
-
vowelAfterDeletionToVowel
→ const Map<
String, String> - Helper map to convert from vowel to new vowel after deletion
-
vowelAndModifierToVowel
→ const Map<
String, String> - Helper map to convert from vowel+modifer to new vowel after insertion
-
vowelAndModifierToVowelWithTrailingConsonant
→ const Map<
String, String> - Helper map to convert from vowel+modifier to new vowel+consonant after insertion
-
vowelToVowelWithTrailingConsonant
→ const Map<
String, String> - Helper map to convert from vowel to new vowel+consonant after insertion